@@ -36,6 +36,7 @@ def sa(	random_start,
 		acceptance = metropolis_acceptance,
 		T_start = 5,
 		T_stop = 0.05,
+		O_stop = None,
 		alpha = .9,
 		repeats = 10**2,
 		copy_state = copy,
@@ -50,6 +51,7 @@ def sa(	random_start,
 		neighbours: **list** of neighbor functions, for one use [neigh]
 		T_start: Starting temperature
 		T_stop: Stopping temperature
+		O_stop: Stopping criterea for objective function value
 		alpha: lower temperature by this factor, after repeats proposals
 		repeats: at each lowering by alpha, do repeats proposals
 		copy = {'copy', 'deepcopy', 'naked'} - copy method
@@ -66,7 +68,7 @@ def sa(	random_start,
 	cost = objective_function(state)
 
 	best_found = copy_state(state)
-	best_found_cost = cost
+	O_min = cost
 
 	T = T_start
 	
@@ -85,7 +87,7 @@ def sa(	random_start,
 		T = T * alpha
 		movements_ratio = movements / repeats
 		
-		pbar.set_description("T: {:5.3f}, M: {:4.2f}, O_min: {:7.4f}, O_current: {:7.4f}".format(T,movements_ratio,best_found_cost,cost))
+		pbar.set_description("T: {:5.3f}, M: {:4.2f}, O_min: {:7.4f}, O_current: {:7.4f}".format(T,movements_ratio,O_min,cost))
 		
 		movements=0
 
@@ -105,13 +107,17 @@ def sa(	random_start,
 
 				state, cost = copy_state(new_state), new_cost
 
-			if cost < best_found_cost:
-				best_found_cost = cost
+			if cost < O_min:
+				O_min = cost
 				best_found = copy_state(state)
 
+		if O_stop is not None:
+			if O_min <= O_stop:
+				break
+
 	if post_annealing:
 		best_found = post_annealing(best_found)
-		best_found_cost = objective_function(best_found)
+		O_min = objective_function(best_found)
 
 	print("---")
 	print("Neighbour Statistics: \n(proportion of proposals which got accepted *and* changed the objective function)")
@@ -119,6 +125,6 @@ def sa(	random_start,
 		print( "   {:32s} : {:5.3f}".format(neighbour[:31], (neighbours_movement_stats[neighbour]/neighbours_tried_stats[neighbour]) ))
 
 	print("---")
-	print("(Local) Minimum Objective Value Found: \n   {:.8f}".format(best_found_cost))
+	print("(Local) Minimum Objective Value Found: \n   {:.8f}".format(O_min))
 
 	return best_found, objective_function(best_found)
\ No newline at end of file
